#[repr(i32)]pub enum ActivityErrorKind {
Unspecified = 0,
Retryable = 1,
Terminal = 2,
PolicyRefused = 3,
}Expand description
Explicit retryability classification for an activity failure.
Variants
Implementations
Sourceimpl ActivityErrorKind
impl ActivityErrorKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.