#[repr(i32)]pub enum NamespaceMintOrigin {
Unspecified = 0,
Worker = 1,
Start = 2,
Explicit = 3,
InferredFromState = 4,
}Expand description
How a namespace came to be minted, carried so the owner records the same provenance the initiating node would have recorded.
Variants
Implementations
Sourceimpl NamespaceMintOrigin
impl NamespaceMintOrigin
Sourcepub fn from_i32(value: i32) -> Option<NamespaceMintOrigin>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<NamespaceMintOrigin>
Use the TryFrom<i32> implementation instead
Converts an i32 to a NamespaceMintOrigin, or None if value is not a valid variant.
Sourceimpl NamespaceMintOrigin
impl NamespaceMintOrigin
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.