#[repr(i32)]pub enum WireErrorCode {
Show 15 variants
Unspecified = 0,
NotFound = 1,
NamespaceDenied = 2,
SequenceConflict = 3,
UnknownQuery = 4,
QueryTimeout = 5,
NotRunning = 6,
Lagged = 7,
InvalidInput = 8,
Backend = 9,
QueryFailed = 10,
DeployDenied = 11,
VersionPinned = 12,
NotOwner = 13,
InvalidState = 14,
}Expand description
Stable client-branchable wire error codes. Messages are informational only.
Variants
Unspecified = 0
NotFound = 1
NamespaceDenied = 2
SequenceConflict = 3
UnknownQuery = 4
QueryTimeout = 5
NotRunning = 6
Lagged = 7
InvalidInput = 8
Backend = 9
QueryFailed = 10
DeployDenied = 11
VersionPinned = 12
NotOwner = 13
InvalidState = 14
Implementations
Sourceimpl WireErrorCode
impl WireErrorCode
Sourceimpl WireErrorCode
impl WireErrorCode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.