pub struct ActivityError {
pub kind: i32,
pub message: String,
pub details: Option<Payload>,
}Expand description
Failure shape mirroring aion-core ActivityError without inferring retryability from the message string.
Fields
kind: i32message: Stringdetails: Option<Payload>Implementations
Sourceimpl ActivityError
impl ActivityError
Sourcepub fn kind(&self) -> ActivityErrorKind
pub fn kind(&self) -> ActivityErrorKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: ActivityErrorKind)
pub fn set_kind(&mut self, value: ActivityErrorKind)
Sets kind to the provided enum value.