pub struct ActivityResult {
pub workflow_id: Option<WorkflowId>,
pub activity_id: Option<ActivityId>,
pub run_id: Option<RunId>,
pub completion_token: String,
pub outcome: Option<Outcome>,
}Expand description
Activity completion or failure reported by a worker.
Fields
workflow_id: Option<WorkflowId>activity_id: Option<ActivityId>run_id: Option<RunId>Concrete run echoed from ActivityTask. Current servers reject absence rather than let a completion bypass the run gate.
completion_token: StringVerbatim token from the ActivityTask. Empty is never interpreted as the current generation: it identifies an incompatible pre-fencing worker and the server rejects the completion.
outcome: Option<Outcome>Trait Implementations
Sourceimpl Clone for ActivityResult
impl Clone for ActivityResult
Sourcefn clone(&self) -> ActivityResult
fn clone(&self) -> ActivityResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ActivityResult
impl Debug for ActivityResult
Sourceimpl Default for ActivityResult
impl Default for ActivityResult
Sourceimpl<'de> Deserialize<'de> for ActivityResult
impl<'de> Deserialize<'de> for ActivityResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ActivityResult
Sourceimpl Hash for ActivityResult
impl Hash for ActivityResult
Sourceimpl Message for ActivityResult
impl Message for ActivityResult
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ActivityResult
impl PartialEq for ActivityResult
Sourceimpl Serialize for ActivityResult
impl Serialize for ActivityResult
impl StructuralPartialEq for ActivityResult