pub struct WireError {
pub code: i32,
pub message: String,
pub error_type: Option<String>,
}Expand description
Wire-safe error value returned by server, client, and worker APIs.
Fields
code: i32message: Stringerror_type: Option<String>Implementations
Sourceimpl WireError
impl WireError
Sourcepub fn code(&self) -> WireErrorCode
pub fn code(&self) -> WireErrorCode
Returns the enum value of code, or the default if the field is set to an invalid enum value.
Sourcepub fn set_code(&mut self, value: WireErrorCode)
pub fn set_code(&mut self, value: WireErrorCode)
Sets code to the provided enum value.
Sourcepub fn error_type(&self) -> &str
pub fn error_type(&self) -> &str
Returns the value of error_type, or the default value if error_type is unset.