pub struct WorkflowVersion {
pub workflow_type: String,
pub content_hash: String,
pub deployed_entry_module: String,
pub entry_function: String,
pub manifest_version: String,
pub loaded_at: String,
pub route_active: bool,
}Expand description
One loaded version of one workflow type, mirroring the engine’s WorkflowVersionInfo listing record.
Fields
workflow_type: Stringcontent_hash: Stringdeployed_entry_module: Stringentry_function: Stringmanifest_version: Stringloaded_at: StringRFC 3339 engine-local load instant.
route_active: boolTrait Implementations
Sourceimpl Clone for WorkflowVersion
impl Clone for WorkflowVersion
Sourcefn clone(&self) -> WorkflowVersion
fn clone(&self) -> WorkflowVersion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkflowVersion
impl Debug for WorkflowVersion
Sourceimpl Default for WorkflowVersion
impl Default for WorkflowVersion
Sourceimpl<'de> Deserialize<'de> for WorkflowVersion
impl<'de> Deserialize<'de> for WorkflowVersion
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WorkflowVersion
Sourceimpl Hash for WorkflowVersion
impl Hash for WorkflowVersion
Sourceimpl Message for WorkflowVersion
impl Message for WorkflowVersion
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for WorkflowVersion
impl PartialEq for WorkflowVersion
Sourceimpl Serialize for WorkflowVersion
impl Serialize for WorkflowVersion
impl StructuralPartialEq for WorkflowVersion